=======
mechmat
=======


.. image:: https://img.shields.io/pypi/v/mechmat.svg
        :target: https://pypi.python.org/pypi/mechmat

.. image:: https://img.shields.io/travis/jellespijker/mechmat.svg
        :target: https://travis-ci.org/jellespijker/mechmat

.. image:: https://readthedocs.org/projects/mechmat/badge/?version=latest
        :target: https://mechmat.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/jellespijker/mechmat/shield.svg
     :target: https://pyup.io/repos/github/jellespijker/mechmat/
     :alt: Updates



Python package for the definition of materials used during mechanical engineering calculations


* Free software: MIT license
* Documentation: https://mechmat.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
